@@ -327,7 +327,7 @@ callback_restart (GtkWidget *widget, GdkEvent *event)
 		      GTK_DIALOG_MODAL,
 		      GTK_MESSAGE_QUESTION,
 		      GTK_BUTTONS_YES_NO,
-		      _("Exit this game?"),
+		      _("Are you sure you want to start a new game?"),
 		      NULL);
 
       gtk_dialog_set_default_response (GTK_DIALOG (mb),
@@ -459,7 +459,7 @@ callback_new_with_seed (GtkWidget *widget, GdkEvent *event)
 		      GTK_DIALOG_MODAL,
 		      GTK_MESSAGE_QUESTION,
 		      GTK_BUTTONS_YES_NO,
-		      _("Exit this game?"),
+		      _("Are you sure you want to start a new game?"),
 		      NULL);
 
       gtk_dialog_set_default_response (GTK_DIALOG (mb),
@@ -526,7 +526,7 @@ callback_new (GtkWidget *widget, GdkEvent *event)
 		      GTK_DIALOG_MODAL,
 		      GTK_MESSAGE_QUESTION,
 		      GTK_BUTTONS_YES_NO,
-		      _("Exit this game?"),
+		      _("Are you sure you want to start a new game?"),
 		      NULL);
 
       gtk_dialog_set_default_response (GTK_DIALOG (mb),
@@ -547,9 +547,7 @@ callback_new (GtkWidget *widget, GdkEvent *event)
 void
 callback_score (GtkWidget *widget, GdkEvent *event)
 {
-  GtkWidget *dialog;
-
-  dialog = score_dialog(); 
+  score_dialog(GTK_WINDOW (main_window)); 
 }
 
 void
@@ -567,11 +565,7 @@ callback_undo (GtkWidget *widget, GdkEvent *event)
 void
 callback_option (GtkWidget *widget, GdkEvent *event)
 {
-  GtkWidget *dialog;
-
-  dialog = option_dialog (main_window);
-
-  gtk_widget_show (dialog);
+  option_dialog (main_window);
 }
 
 
@@ -622,7 +616,7 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
 		      GTK_DIALOG_MODAL,
 		      GTK_MESSAGE_QUESTION,
 		      GTK_BUTTONS_NONE,
-		      _("Really exit GNOME Freecell?"),
+		      _("Are you sure you want to quit Freecell?"),
 		      NULL);
       gtk_dialog_add_buttons (GTK_DIALOG (mb),
 			      GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
@@ -649,7 +643,7 @@ void
 callback_about (GtkWidget *widget, GdkEvent *event)
 {
   GdkPixbuf *pixbuf = NULL;
-  GtkWidget *about;
+  static GtkWidget *about = NULL;
   gchar *authors[] = {
     N_("Changwoo Ryu."),
     NULL
@@ -661,6 +655,11 @@ callback_about (GtkWidget *widget, GdkEvent *event)
 
   const gchar *translator_credits = _("translator_credits");
 
+  if (about != NULL) {
+    gtk_window_present (GTK_WINDOW(about));
+    return;
+  }
+
 #ifndef ELEMENTS  
 #define ELEMENTS(x) (sizeof(x) / sizeof(x[0]))
 #endif /* ELEMENTS */
@@ -672,13 +671,16 @@ callback_about (GtkWidget *widget, GdkEvent *event)
   }
 
   {
-	  char *filename = NULL;
+	  char *filename;
 	  
 	  filename = gnome_program_locate_file (NULL,
 			  GNOME_FILE_DOMAIN_APP_PIXMAP,
 			  "gnome-cardgame.png", FALSE, NULL);
 
-	  pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+	  if (filename != NULL) {
+	    pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+	    g_free (filename);
+	  }
   }
 
   about = gnome_about_new (_("Freecell"), VERSION,
@@ -689,6 +691,8 @@ callback_about (GtkWidget *widget, GdkEvent *event)
 			   strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			   pixbuf);
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (main_window));
+  g_signal_connect (G_OBJECT(about), "destroy", G_CALLBACK(gtk_widget_destroyed), &about);
+  if (pixbuf != NULL) g_object_unref (pixbuf);
   gtk_widget_show (about);
 }
 
