@@ -102,7 +102,7 @@ Tetris::Tetris(int cmdlLevel):
 	
 	GnomeUIInfo help_menu[] = 
 	{
-		GNOMEUIINFO_HELP((gpointer)"gnometris"),
+		/* FIXME GNOMEUIINFO_HELP((gpointer)"gnometris"), */
 		GNOMEUIINFO_MENU_ABOUT_ITEM(gameAbout, this),
 		GNOMEUIINFO_END
 	};
@@ -215,7 +215,7 @@ Tetris::setupPixmap()
 	char *pixname, *fullpixname;
 	
 	pixname = g_strdup_printf("gnometris/%s", blockPixmap);
-	fullpixname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, pixname, FALSE, NULL);
+	fullpixname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, pixname, FALSE, NULL);
 	g_free(pixname);
 
 	if (!g_file_test (fullpixname, G_FILE_TEST_EXISTS))
@@ -262,7 +262,7 @@ Tetris::setupPixmap()
 	}
 
 	pixname = g_strdup_printf("gnometris/bg/%s", bgPixmap);
-	fullpixname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, pixname, FALSE, NULL);
+	fullpixname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, pixname, FALSE, NULL);
 	g_free(pixname);
 
 	if(bgimage)
@@ -408,7 +408,7 @@ void
 Tetris::setRotateCounterClockWise(GtkWidget *widget, void *d)
 {
 	Tetris *t = (Tetris*) d;
-	gconf_client_set_bool (t->gconf_client, "/apps/gnometris/options/rotate_counter_click_wise", GTK_TOGGLE_BUTTON(widget)->active, NULL);
+	gconf_client_set_bool (t->gconf_client, "/apps/gnometris/options/rotate_counter_clock_wise", GTK_TOGGLE_BUTTON(widget)->active, NULL);
 }
 
 void
@@ -464,7 +464,7 @@ Tetris::fillMenu(GtkWidget *menu, char *pixname, char *dirname,
 		 GtkSignalFunc selectFunc, bool addnone /*= false*/)
 {
 	struct dirent *e;
-	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, dirname, FALSE, NULL);
+	char *dname = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, dirname, FALSE, NULL);
 	DIR *dir;
 	int itemno = 0;
 	
@@ -525,8 +525,10 @@ Tetris::gameProperties(GtkWidget *widget, void *d)
         
 	Tetris *t = (Tetris*) d;
 	
-	if (t->setupdialog) 
+	if (t->setupdialog) {
+		gtk_window_present (GTK_WINDOW(t->setupdialog));
 		return FALSE;
+	}
 
 	/* create the dialog */
 	t->setupdialog =
@@ -537,7 +539,6 @@ Tetris::gameProperties(GtkWidget *widget, void *d)
 					    NULL);
 
 	gtk_container_set_border_width(GTK_CONTAINER(t->setupdialog), 10);
-	GTK_WINDOW(t->setupdialog)->position = GTK_WIN_POS_MOUSE;
 	g_signal_connect (t->setupdialog, "close",
 			  G_CALLBACK (setupdialogDestroy), d);
 	g_signal_connect (t->setupdialog, "response",
@@ -794,7 +795,9 @@ Tetris::eventHandler(GtkWidget *widget, GdkEvent *event, void *d)
 	
 	if (event->type == GDK_KEY_PRESS)
 	{
-		if (((GdkEventKey*)event)->keyval == GDK_space)
+		int keyval = ((GdkEventKey*)event)->keyval;
+
+		if ((keyval == GDK_p) || (keyval == GDK_P))
 		{
 			t->togglePause();
 			return TRUE;
@@ -803,10 +806,10 @@ Tetris::eventHandler(GtkWidget *widget, GdkEvent *event, void *d)
 	
 	if (t->paused)
 		return FALSE;
-	
+
 	bool res = false;
 	bool keyEvent = false;
-	
+
 	switch (event->type)
 	{
 	case GDK_KEY_PRESS: 
@@ -843,14 +846,23 @@ Tetris::eventHandler(GtkWidget *widget, GdkEvent *event, void *d)
 	case GDK_KEY_RELEASE:
 	{
 		GdkEventKey *e = (GdkEventKey*)event;
-		if (e->keyval == GDK_Down)
+
+		switch (e->keyval)
 		{
+		case GDK_Down:
 			keyEvent = true;
 			if (t->fastFall)
 			{
 				t->fastFall = false;
  				t->generateTimer(t->scoreFrame->getLevel());
 			}
+			break;
+		case GDK_space:
+			t->ops->dropBlock();
+			res = TRUE;
+			break;
+		default:
+			return FALSE;
 		}
 		break;
 	}
@@ -911,7 +923,13 @@ Tetris::endOfGame()
 void
 Tetris::showScores(gchar *title, guint pos)
 {
-	gnome_scores_display(title, "gnometris", 0, pos);
+	GtkWidget *dialog;
+
+	dialog = gnome_scores_display(title, "gnometris", 0, pos);
+	if (dialog != NULL) {
+		gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(this->getWidget()));
+		gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+	}
 }
 
 int
@@ -956,22 +974,51 @@ int
 Tetris::gameAbout(GtkWidget *widget, void *d)
 {
 	Tetris *t = (Tetris*) d;
-
-	GtkWidget *about;
+	GdkPixbuf *pixbuf = NULL;
+	static GtkWidget *about = NULL;
 
 	const gchar *authors[] = {"J. Marcin Gorycki", 0};
-	
+
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
+
+	if (about != NULL) {
+		gtk_window_present (GTK_WINDOW(about));
+		return TRUE;
+	}
+        {
+		char *filename = NULL;
+
+		filename = gnome_program_locate_file (NULL,
+				GNOME_FILE_DOMAIN_APP_PIXMAP, 
+				"gnome-gtetris.png",
+				TRUE, NULL);
+		if (filename != NULL)
+		{
+			pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+			g_free (filename);
+		}
+	}
+
 	about = gnome_about_new("Gnometris", 
-				TETRIS_VERSION, 
+				VERSION, 
 				"(C) 2000 J. Marcin Gorycki",
 				_("Written for my wife, Matylda\n"
 				  "Send comments and bug reports to: "
 				  "janusz.gorycki@intel.com"),
 				(const char **)authors,
-				NULL,
-				NULL,
-				NULL);
-
+				(const char **)documenters,
+				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				pixbuf);
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+	
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (t->getWidget()));
+	g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
 	gtk_widget_show(about);
 
 	return TRUE;
