@@ -26,7 +26,6 @@
 
 #define APPNAME "gnotravex"
 #define APPNAME_LONG "GNOME Tetravex"
-#define GNOTRAVEX_VERSION "0.20"
 
 #define TILE_SIZE 51
 
@@ -1110,13 +1109,17 @@ void about_cb(GtkWidget *widget, gpointer data){
   }
 
   about = gnome_about_new(_(APPNAME_LONG), 
-			  GNOTRAVEX_VERSION, 
+			  VERSION, 
 			  "(C) 1998 Lars Rydlinge",
 			  _("Tetravex clone\n(Comments to: Lars.Rydlinge@HIG.SE)"), 
 			  (const char **)authors,
                           (const char **)documenters,
                           strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			  pixbuf);
+	
+  if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);	  
+  
   gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
   g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
   gtk_widget_show(about);
