@@ -1388,6 +1388,10 @@ about_callback (GtkWidget *widget, gpointer data)
 				 (const gchar **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				pixbuf);
+	
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+	
 	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
 	gtk_widget_show (about);
 }
